@@ -156,23 +156,22 @@ def _signal_fixpeaks_kubios(peaks, sampling_rate=1000, iterative=True, show=Fals
 
     if iterative:
 
-        # Iteratively apply the artifact correction until the number of artifact
-        # reaches an equilibrium (i.e., the number of artifacts does not change
-        # anymore from one iteration to the next).
-        n_artifacts_previous = np.inf
+        # Iteratively apply the artifact correction until the number
+        # of artifacts stops decreasing.
         n_artifacts_current = sum([len(i) for i in artifacts.values()])
 
-        previous_diff = 0
+        while True:
 
-        while n_artifacts_current - n_artifacts_previous != previous_diff:
-
-            previous_diff = n_artifacts_previous - n_artifacts_current
-
-            artifacts, subspaces = _find_artifacts(peaks_clean, sampling_rate=sampling_rate)
-            peaks_clean = _correct_artifacts(artifacts, peaks_clean)
+            new_artifacts, new_subspaces = _find_artifacts(peaks_clean, sampling_rate=sampling_rate)
 
             n_artifacts_previous = n_artifacts_current
-            n_artifacts_current = sum([len(i) for i in artifacts.values()])
+            n_artifacts_current = sum([len(i) for i in new_artifacts.values()])
+            if n_artifacts_current >= n_artifacts_previous:
+                break
+
+            artifacts = new_artifacts
+            subspaces = new_subspaces
+            peaks_clean = _correct_artifacts(artifacts, peaks_clean)
 
     if show:
         _plot_artifacts_lipponen2019(artifacts, subspaces)
@@ -229,7 +228,7 @@ def _find_artifacts(peaks, c1=0.13, c2=0.17, alpha=5.2, window_width=91, medfilt
 
     # Compute mRRs: time series of deviation of RRs from median.
     df = pd.DataFrame({"signal": rr})
-    medrr = df.rolling(medfilt_order, center=True, min_periods=1).median().signal.to_numpy()
+    medrr = df.rolling(medfilt_order, center=True, min_periods=1).median().signal.values
     mrrs = rr - medrr
     mrrs[mrrs < 0] = mrrs[mrrs < 0] * 2
     # Normalize by threshold.
@@ -314,8 +313,8 @@ def _find_artifacts(peaks, c1=0.13, c2=0.17, alpha=5.2, window_width=91, medfilt
 def _compute_threshold(signal, alpha, window_width):
 
     df = pd.DataFrame({"signal": np.abs(signal)})
-    q1 = df.rolling(window_width, center=True, min_periods=1).quantile(0.25).signal.to_numpy()
-    q3 = df.rolling(window_width, center=True, min_periods=1).quantile(0.75).signal.to_numpy()
+    q1 = df.rolling(window_width, center=True, min_periods=1).quantile(0.25).signal.values
+    q3 = df.rolling(window_width, center=True, min_periods=1).quantile(0.75).signal.values
     th = alpha * ((q3 - q1) / 2)
 
     return th
@@ -557,4 +556,4 @@ def _interpolate_missing(peaks, interval, interval_max, sampling_rate):
 def _period_to_location(period, sampling_rate=1000, first_location=0):
     location = np.cumsum(period * sampling_rate)
     location = location - (location[0] - first_location)
-    return location.astype(np.int)
+    return location.astype(int)
